<?php
/* Copyright (C) 2010 Regis Houssin        <regis@dolibarr.fr>
 * Copyright (C) 2010 Laurent Destailleur  <eldy@users.sourceforge.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

/**
 *      \defgroup   workflow     Module workflow
 *      \brief      Workflow management
 *      \version    $Id: modWorkflow.class.php,v 1.11 2011/08/01 13:26:22 hregis Exp $
 */

/**
 *      \file       htdocs/includes/modules/modWorkflow.class.php
 *      \ingroup    workflow
 *      \brief      File to describe and activate module Workflow
 */

include_once(DOL_DOCUMENT_ROOT ."/includes/modules/DolibarrModules.class.php");


/**
 *  \class      modWorkflow
 *  \brief      Classe de description et activation du module Workflow
 */
class modWorkflow extends DolibarrModules
{

    /**
     *   \brief      Constructeur. Definit les noms, constantes et boites
     *   \param      DB      handler d'acces base
     */
    function modWorkflow($DB)
    {
        $this->db = $DB ;

        // Id for module (must be unique).
        // Use here a free id (See in Home -> System information -> Dolibarr for list of used modules id).
        $this->numero = 6000 ;
        // Key text used to identify module (for permissions, menus, etc...)
        $this->rights_class = 'workflow';

        $this->family = "technic";
        // Module label (no space allowed), used if translation string 'ModuleXXXName' not found (where XXX is value of numeric property 'numero' of module)
        $this->name = preg_replace('/^mod/i','',get_class($this));
        // Module description, used if translation string 'ModuleXXXDesc' not found (where XXX is value of numeric property 'numero' of module)
        $this->description = "Workflow management";
        // Possible values for version are: 'development', 'experimental', 'dolibarr' or version
        $this->version = 'dolibarr';
        // Key used in llx_const table to save module status enabled/disabled (where MYMODULE is value of property name of module in uppercase)
        $this->const_name = 'MAIN_MODULE_'.strtoupper($this->name);
        // Where to store the module in setup page (0=common,1=interface,2=others,3=very specific)
        $this->special = 2;
        // Name of png file (without png) used for this module.
        // If file is in theme/yourtheme/img directory under name object_pictovalue.png, use this->picto='pictovalue'
        // If file is in module/img directory under name object_pictovalue.png, use this->picto='pictovalue@module'
        $this->picto='technic';

        // Defined if the directory /mymodule/includes/triggers/ contains triggers or not
        $this->triggers = 1;

        // Data directories to create when module is enabled
        $this->dirs = array("/workflow/temp");

        // Relative path to module style sheet if exists. Example: '/mymodule/mycss.css'.
        $this->style_sheet = '';

        // Config pages. Put here list of php page names stored in admmin directory used to setup module.
        $this->config_page_url = 'workflow.php';

        // Dependencies
        $this->depends = array();       // List of modules id that must be enabled if this module is enabled
        $this->requiredby = array();    // List of modules id to disable if this one is disabled
        $this->phpmin = array(5,2);                 // Minimum version of PHP required by module
        $this->need_dolibarr_version = array(2,8);  // Minimum version of Dolibarr required by module
        $this->langfiles = array("@workflow");

        // Constants
        // List of particular constants to add when module is enabled
        //Example: $this->const=array(0=>array('MODULE_MY_NEW_CONST1','chaine','myvalue','This is a constant to add',0),
        //                            1=>array('MODULE_MY_NEW_CONST2','chaine','myvalue','This is another constant to add',0) );
        $this->const=array();

        // Boxes
        $this->boxes = array();
        //$this->boxes[0][1] = "box_workflow@workflow";

        // Permissions
        $this->rights = array();
        $r=0;

        /*
        $r++;
        $this->rights[$r][0] = 6001; // id de la permission
        $this->rights[$r][1] = "Lire les workflow"; // libelle de la permission
        $this->rights[$r][2] = 'r'; // type de la permission (deprecie a ce jour)
        $this->rights[$r][3] = 1; // La permission est-elle une permission par defaut
        $this->rights[$r][4] = 'read';
        */

        // Main menu entries
        $this->menus = array();         // List of menus to add
        $r=0;
        /*
        $this->menu[$r]=array('fk_menu'=>0,
                                'type'=>'top',
                                'titre'=>'Workflow',
                                'mainmenu'=>'workflow',
                                'leftmenu'=>'1',
                                'url'=>'/workflow/index.php',
                                'langs'=>'@workflow',
                                'position'=>100,
                                'perms'=>'$user->rights->workflow->read',
                                'enabled'=>'$conf->workflow->enabled',
                                'target'=>'',
                                'user'=>0);
        $r++;

        $this->menu[$r]=array(  'fk_menu'=>'r=0',
                                'type'=>'left',
                                'titre'=>'Workflow',
                                'mainmenu'=>'workflow',
                                'url'=>'/workflow/index.php',
                                'langs'=>'@workflow',
                                'position'=>101,
                                'enabled'=>1,
                                'perms'=>'$user->rights->workflow->read',
                                'target'=>'',
                                'user'=>0);
        $r++;
        */
    }


    /**
     *   \brief      Fonction appelee lors de l'activation du module. Insere en base les constantes, boites, permissions du module.
     *               Definit egalement les repertoires de donnees a creer pour ce module.
     */
    function init()
    {
        //$result=$this->load_tables();

        return $this->_init($sql);
    }

    /**
     *    \brief      Fonction appelee lors de la desactivation d'un module.
     *                Supprime de la base les constantes, boites et permissions du module.
     */
    function remove()
    {
        $sql = array();

        return $this->_remove($sql);
    }

    /**
     *      \brief      Create tables and keys required by module
     *                  This function is called by this->init.
     *      \return     int     <=0 if KO, >0 if OK
     */
    function load_tables()
    {
        return $this->_load_tables('/workflow/sql/');
    }
}
?>
